@@ -28,6 +28,7 @@ project "netlist"
 
 	defines {
 		"__STDC_CONSTANT_MACROS",
+		"NL_USE_ACADEMIC_SOLVERS=0",
 	}
 
 	includedirs {
@@ -233,4 +234,6 @@ project "netlist"
 		MAME_DIR .. "src/lib/netlist/macro/nlm_opamp.h",
 		MAME_DIR .. "src/lib/netlist/macro/nlm_other.cpp",
 		MAME_DIR .. "src/lib/netlist/macro/nlm_other.h",
+
+		MAME_DIR .. "src/lib/netlist/generated/static_solvers.cpp",
 	}
