@@ -459,7 +459,11 @@ links {
 
 includedirs {
 	MAME_DIR .. "src/lib",
-  MAME_DIR .. "src/lib/netlist",
+	MAME_DIR .. "src/lib/netlist",
+}
+
+defines {
+  "NL_DISABLE_DYNAMIC_LOAD=1",
 }
 
 files {
@@ -467,13 +471,13 @@ files {
 }
 
 configuration { "mingw*" }
-  linkoptions{
-	"-municode",
-  }
+	linkoptions{
+		"-municode",
+	}
 configuration { "vs*" }
-  flags {
-	"Unicode",
-  }
+	flags {
+		"Unicode",
+	}
 
 configuration { "mingw*" or "vs*" }
 	targetextension ".exe"
@@ -504,7 +508,7 @@ links {
 
 includedirs {
 	MAME_DIR .. "src/lib",
-  MAME_DIR .. "src/lib/netlist",
+	MAME_DIR .. "src/lib/netlist",
 }
 
 files {
@@ -512,13 +516,13 @@ files {
 }
 
 configuration { "mingw*" }
-  linkoptions{
-	"-municode",
-  }
+	linkoptions{
+		"-municode",
+	}
 configuration { "vs*" }
-  flags {
-	"Unicode",
-  }
+	flags {
+		"Unicode",
+	}
 
 configuration { "mingw*" or "vs*" }
 	targetextension ".exe"
