@@ -399,6 +399,18 @@ if (VIDEOS["HD66421"]~=null) then
 	}
 end
 
+--------------------------------------------------
+--
+--@src/devices/video/hlcd0488.h,VIDEOS["HLCD0488"] = true
+--------------------------------------------------
+
+if (VIDEOS["HLCD0488"]~=null) then
+	files {
+		MAME_DIR .. "src/devices/video/hlcd0488.cpp",
+		MAME_DIR .. "src/devices/video/hlcd0488.h",
+	}
+end
+
 --------------------------------------------------
 --
 --@src/devices/video/hlcd0515.h,VIDEOS["HLCD0515"] = true
@@ -745,6 +757,18 @@ if (VIDEOS["PCD8544"]~=null) then
 	}
 end
 
+--------------------------------------------------
+--
+--@src/devices/video/pcf2100.h,VIDEOS["PCF2100"] = true
+--------------------------------------------------
+
+if (VIDEOS["PCF2100"]~=null) then
+	files {
+		MAME_DIR .. "src/devices/video/pcf2100.cpp",
+		MAME_DIR .. "src/devices/video/pcf2100.h",
+	}
+end
+
 --------------------------------------------------
 --
 --@src/devices/video/polylgcy.h,VIDEOS["POLY"] = true
