@@ -20,7 +20,7 @@
 //  GLOBAL VARIABLES
 //**************************************************************************
 
-const device_type BML3BUS_KANJI = &device_creator<bml3bus_kanji_device>;
+DEFINE_DEVICE_TYPE(BML3BUS_KANJI, bml3bus_kanji_device, "bml3kanji", "Hitachi MP-9740 Kanji Character ROM Card")
 
 #define KANJI_ROM_REGION  "kanji_rom"
 
@@ -29,24 +29,11 @@ ROM_START( kanji )
 	ROM_LOAD("kanji.rom", 0x00000, 0x20000, BAD_DUMP CRC(de99a726) SHA1(65fead5d0d779b242f6e0ac25fcc9899dc343101))
 ROM_END
 
-MACHINE_CONFIG_FRAGMENT( kanji )
-	// nothing to add
-MACHINE_CONFIG_END
 
 /***************************************************************************
     FUNCTION PROTOTYPES
 ***************************************************************************/
 
-//-------------------------------------------------
-//  machine_config_additions - device-specific
-//  machine configurations
-//-------------------------------------------------
-
-machine_config_constructor bml3bus_kanji_device::device_mconfig_additions() const
-{
-	return MACHINE_CONFIG_NAME( kanji );
-}
-
 //-------------------------------------------------
 //  rom_region - device-specific ROM region
 //-------------------------------------------------
@@ -73,7 +60,7 @@ WRITE8_MEMBER( bml3bus_kanji_device::bml3_kanji_w )
 //**************************************************************************
 
 bml3bus_kanji_device::bml3bus_kanji_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock) :
-	device_t(mconfig, BML3BUS_KANJI, "Hitachi MP-9740 Kanji Character ROM Card", tag, owner, clock, "bml3kanji", __FILE__),
+	device_t(mconfig, BML3BUS_KANJI, tag, owner, clock),
 	device_bml3bus_card_interface(mconfig, *this), m_kanji_addr(0), m_rom(nullptr)
 {
 }
@@ -85,14 +72,11 @@ bml3bus_kanji_device::bml3bus_kanji_device(const machine_config &mconfig, const
 
 void bml3bus_kanji_device::device_start()
 {
-	// set_bml3bus_device makes m_slot valid
-	set_bml3bus_device();
-
 	m_rom = memregion(KANJI_ROM_REGION)->base();
 
 	// install into memory
-	address_space &space_prg = machine().firstcpu->space(AS_PROGRAM);
-	space_prg.install_readwrite_handler(0xff75, 0xff76, read8_delegate( FUNC(bml3bus_kanji_device::bml3_kanji_r), this), write8_delegate(FUNC(bml3bus_kanji_device::bml3_kanji_w), this) );
+	address_space &space_prg = space();
+	space_prg.install_readwrite_handler(0xff75, 0xff76, read8_delegate(*this, FUNC(bml3bus_kanji_device::bml3_kanji_r)), write8_delegate(*this, FUNC(bml3bus_kanji_device::bml3_kanji_w)));
 }
 
 void bml3bus_kanji_device::device_reset()
