@@ -141,7 +141,7 @@ void dmv_k806_device::io_read(int ifsel, offs_t offset, uint8_t &data)
 {
 	uint8_t jumpers = m_jumpers->read();
 	if (BIT(jumpers, ifsel) && ((!BIT(offset, 3) && BIT(jumpers, 5)) || (BIT(offset, 3) && BIT(jumpers, 6))))
-		data = m_mcu->upi41_master_r(machine().dummy_space(), offset & 1);
+		data = m_mcu->upi41_master_r(offset & 1);
 }
 
 void dmv_k806_device::io_write(int ifsel, offs_t offset, uint8_t data)
@@ -149,7 +149,7 @@ void dmv_k806_device::io_write(int ifsel, offs_t offset, uint8_t data)
 	uint8_t jumpers = m_jumpers->read();
 	if (BIT(jumpers, ifsel) && ((!BIT(offset, 3) && BIT(jumpers, 5)) || (BIT(offset, 3) && BIT(jumpers, 6))))
 	{
-		m_mcu->upi41_master_w(machine().dummy_space(), offset & 1, data);
+		m_mcu->upi41_master_w(offset & 1, data);
 		out_int(CLEAR_LINE);
 	}
 }
