@@ -1,13 +1,15 @@
 // license:BSD-3-Clause
 // copyright-holders:Wilbert Pol
+#ifndef MAME_BUS_ISA_CGA_H
+#define MAME_BUS_ISA_CGA_H
+
 #pragma once
 
-#ifndef __ISA_CGA_H__
-#define __ISA_CGA_H__
-
-#include "emu.h"
 #include "isa.h"
 #include "video/mc6845.h"
+#include "emupal.h"
+#include "screen.h"
+
 
 //**************************************************************************
 //  TYPE DEFINITIONS
@@ -25,43 +27,44 @@ class isa8_cga_device :
 	friend class isa8_cga_pc1512_device;
 
 public:
+	static constexpr feature_type imperfect_features() { return feature::GRAPHICS; }
 	// construction/destruction
 	isa8_cga_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock);
-	isa8_cga_device(const machine_config &mconfig, device_type type, const char *name, const char *tag, device_t *owner, uint32_t clock, const char *shortname, const char *source);
 
 	virtual MC6845_UPDATE_ROW( crtc_update_row );
-	MC6845_UPDATE_ROW( cga_text_inten_update_row );
-	MC6845_UPDATE_ROW( cga_text_inten_comp_grey_update_row );
-	MC6845_UPDATE_ROW( cga_text_inten_alt_update_row );
-	MC6845_UPDATE_ROW( cga_text_blink_update_row );
-	MC6845_UPDATE_ROW( cga_text_blink_update_row_si );
-	MC6845_UPDATE_ROW( cga_text_blink_alt_update_row );
+	template<bool blink, bool si, bool comp, bool alt, int width> MC6845_UPDATE_ROW( cga_text );
 	MC6845_UPDATE_ROW( cga_gfx_4bppl_update_row );
 	MC6845_UPDATE_ROW( cga_gfx_4bpph_update_row );
 	MC6845_UPDATE_ROW( cga_gfx_2bpp_update_row );
 	MC6845_UPDATE_ROW( cga_gfx_1bpp_update_row );
 
-	// optional information overrides
-	virtual machine_config_constructor device_mconfig_additions() const override;
-	virtual ioport_constructor device_input_ports() const override;
-	virtual const tiny_rom_entry *device_rom_region() const override;
-
 protected:
+	isa8_cga_device(const machine_config &mconfig, device_type type, const char *tag, device_t *owner, uint32_t clock);
+
+	required_device<mc6845_device> m_crtc;
 	required_ioport m_cga_config;
 
 	// device-level overrides
 	virtual void device_start() override;
 	virtual void device_reset() override;
+
+	// optional information overrides
+	virtual void device_add_mconfig(machine_config &config) override;
+	virtual ioport_constructor device_input_ports() const override;
+	virtual const tiny_rom_entry *device_rom_region() const override;
+
+	virtual uint32_t screen_update(screen_device &screen, bitmap_rgb32 &bitmap, const rectangle &cliprect);
+
+	DECLARE_WRITE_LINE_MEMBER( hsync_changed );
+	DECLARE_WRITE_LINE_MEMBER( vsync_changed );
+
 public:
 	void mode_control_w(uint8_t data);
 	void set_palette_luts();
 	void plantronics_w(uint8_t data);
 	virtual DECLARE_READ8_MEMBER( io_read );
 	virtual DECLARE_WRITE8_MEMBER( io_write );
-	DECLARE_WRITE_LINE_MEMBER( hsync_changed );
-	DECLARE_WRITE_LINE_MEMBER( vsync_changed );
-	virtual uint32_t screen_update(screen_device &screen, bitmap_rgb32 &bitmap, const rectangle &cliprect);
-	MC6845_RECONFIGURE(reconfigure);
+
 public:
 	int     m_framecnt;
 
@@ -84,10 +87,13 @@ public:
 	offs_t  m_start_offset;
 	required_device<palette_device> m_palette;
 	required_device<screen_device> m_screen;
+
+private:
+	MC6845_RECONFIGURE(reconfigure);
 };
 
 // device type definition
-extern const device_type ISA8_CGA;
+DECLARE_DEVICE_TYPE(ISA8_CGA, isa8_cga_device)
 
 
 // ======================> isa8_cga_superimpose_device
@@ -98,11 +104,12 @@ class isa8_cga_superimpose_device :
 public:
 	// construction/destruction
 	isa8_cga_superimpose_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock);
-	isa8_cga_superimpose_device(const machine_config &mconfig, device_type type, const char *name, const char *tag, device_t *owner, uint32_t clock, const char *shortname, const char *source);
+protected:
+	isa8_cga_superimpose_device(const machine_config &mconfig, device_type type, const char *tag, device_t *owner, uint32_t clock);
 };
 
 // device type definition
-extern const device_type ISA8_CGA_SUPERIMPOSE;
+DECLARE_DEVICE_TYPE(ISA8_CGA_SUPERIMPOSE, isa8_cga_superimpose_device)
 
 
 // ======================> isa8_poisk2_device
@@ -118,7 +125,7 @@ public:
 };
 
 // device type definition
-extern const device_type ISA8_CGA_POISK2;
+DECLARE_DEVICE_TYPE(ISA8_CGA_POISK2, isa8_cga_poisk2_device)
 
 
 // ======================> isa8_pc1512_device
@@ -161,7 +168,7 @@ public:
 };
 
 // device type definition
-extern const device_type ISA8_CGA_PC1512;
+DECLARE_DEVICE_TYPE(ISA8_CGA_PC1512, isa8_cga_pc1512_device)
 
 // ======================> isa8_wyse700_device
 
@@ -191,7 +198,7 @@ public:
 };
 
 // device type definition
-extern const device_type ISA8_WYSE700;
+DECLARE_DEVICE_TYPE(ISA8_WYSE700, isa8_wyse700_device)
 
 // ======================> isa8_ec1841_0002_device
 
@@ -217,7 +224,7 @@ public:
 };
 
 // device type definition
-extern const device_type ISA8_EC1841_0002;
+DECLARE_DEVICE_TYPE(ISA8_EC1841_0002, isa8_ec1841_0002_device)
 
 // ======================> isa8_cga_iskr1031_device
 
@@ -231,7 +238,7 @@ public:
 };
 
 // device type definition
-extern const device_type ISA8_CGA_ISKR1030M;
+DECLARE_DEVICE_TYPE(ISA8_CGA_ISKR1030M, isa8_cga_iskr1030m_device)
 
 // ======================> isa8_cga_iskr1031_device
 
@@ -245,7 +252,7 @@ public:
 };
 
 // device type definition
-extern const device_type ISA8_CGA_ISKR1031;
+DECLARE_DEVICE_TYPE(ISA8_CGA_ISKR1031, isa8_cga_iskr1031_device)
 
 // ======================> isa8_cga_mc1502_device
 
@@ -260,7 +267,7 @@ public:
 };
 
 // device type definition
-extern const device_type ISA8_CGA_MC1502;
+DECLARE_DEVICE_TYPE(ISA8_CGA_MC1502, isa8_cga_mc1502_device)
 
 
 class isa8_cga_m24_device :
@@ -269,21 +276,41 @@ class isa8_cga_m24_device :
 public:
 	// construction/destruction
 	isa8_cga_m24_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock);
-	virtual machine_config_constructor device_mconfig_additions() const override;
-	// optional information overrides
-	//virtual const rom_entry *device_rom_region() const;
 	virtual DECLARE_READ8_MEMBER( io_read ) override;
 	virtual DECLARE_WRITE8_MEMBER( io_write ) override;
 	virtual MC6845_UPDATE_ROW( crtc_update_row ) override;
 	MC6845_UPDATE_ROW( m24_gfx_1bpp_m24_update_row );
 	MC6845_RECONFIGURE(reconfigure);
+
 protected:
+	isa8_cga_m24_device(const machine_config &mconfig, device_type type, const char *tag, device_t *owner, uint32_t clock);
 	virtual void device_reset() override;
-private:
+	// optional information overrides
+	virtual void device_add_mconfig(machine_config &config) override;
+	virtual const tiny_rom_entry *device_rom_region() const override;
 	uint8_t m_mode2, m_index;
 };
 
 // device type definition
-extern const device_type ISA8_CGA_M24;
+DECLARE_DEVICE_TYPE(ISA8_CGA_M24, isa8_cga_m24_device)
 
-#endif  /* __ISA_CGA_H__ */
+class isa8_cga_cportiii_device :
+		public isa8_cga_m24_device
+{
+public:
+	isa8_cga_cportiii_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock);
+	DECLARE_READ8_MEMBER(port_13c6_r);
+	DECLARE_WRITE8_MEMBER(port_13c6_w);
+	DECLARE_READ8_MEMBER(port_23c6_r);
+	DECLARE_WRITE8_MEMBER(port_23c6_w);
+	DECLARE_READ8_MEMBER(char_ram_read);
+	DECLARE_WRITE8_MEMBER(char_ram_write);
+protected:
+	virtual void device_reset() override;
+	virtual void device_add_mconfig(machine_config &config) override;
+	virtual const tiny_rom_entry *device_rom_region() const override;
+};
+
+DECLARE_DEVICE_TYPE(ISA8_CGA_CPORTIII, isa8_cga_cportiii_device)
+
+#endif  // MAME_BUS_ISA_CGA_H
