@@ -6,6 +6,7 @@
 
 ***************************************************************************/
 
+#include "emu.h"
 #include "sv805.h"
 
 
@@ -13,30 +14,25 @@
 //  DEVICE DEFINITIONS
 //**************************************************************************
 
-const device_type SV805 = &device_creator<sv805_device>;
+DEFINE_DEVICE_TYPE(SV805, sv805_device, "sv805", "SV-805 RS-232 Interface")
 
 //-------------------------------------------------
-//  machine_config_additions - device-specific
-//  machine configurations
+//  device_add_mconfig - add device configuration
 //-------------------------------------------------
 
-static MACHINE_CONFIG_FRAGMENT( sv805 )
-	MCFG_DEVICE_ADD("uart", INS8250, XTAL_3_072MHz)
-	MCFG_INS8250_OUT_INT_CB(WRITELINE(sv805_device, uart_intr_w))
-	MCFG_INS8250_OUT_TX_CB(DEVWRITELINE("rs232", rs232_port_device, write_txd))
-	MCFG_INS8250_OUT_DTR_CB(DEVWRITELINE("rs232", rs232_port_device, write_dtr))
-	MCFG_INS8250_OUT_RTS_CB(DEVWRITELINE("rs232", rs232_port_device, write_rts))
-
-	MCFG_RS232_PORT_ADD("rs232", default_rs232_devices, nullptr)
-	MCFG_RS232_RXD_HANDLER(DEVWRITELINE("uart", ins8250_uart_device, rx_w))
-	MCFG_RS232_DCD_HANDLER(DEVWRITELINE("uart", ins8250_uart_device, dcd_w))
-	MCFG_RS232_DSR_HANDLER(DEVWRITELINE("uart", ins8250_uart_device, dsr_w))
-	MCFG_RS232_CTS_HANDLER(DEVWRITELINE("uart", ins8250_uart_device, cts_w))
-MACHINE_CONFIG_END
-
-machine_config_constructor sv805_device::device_mconfig_additions() const
+void sv805_device::device_add_mconfig(machine_config &config)
 {
-	return MACHINE_CONFIG_NAME( sv805 );
+	INS8250(config, m_uart, XTAL(3'072'000));
+	m_uart->out_int_callback().set(FUNC(sv805_device::uart_intr_w));
+	m_uart->out_tx_callback().set(m_rs232, FUNC(rs232_port_device::write_txd));
+	m_uart->out_dtr_callback().set(m_rs232, FUNC(rs232_port_device::write_dtr));
+	m_uart->out_rts_callback().set(m_rs232, FUNC(rs232_port_device::write_rts));
+
+	RS232_PORT(config, m_rs232, default_rs232_devices, nullptr);
+	m_rs232->rxd_handler().set(m_uart, FUNC(ins8250_uart_device::rx_w));
+	m_rs232->dcd_handler().set(m_uart, FUNC(ins8250_uart_device::dcd_w));
+	m_rs232->dsr_handler().set(m_uart, FUNC(ins8250_uart_device::dsr_w));
+	m_rs232->cts_handler().set(m_uart, FUNC(ins8250_uart_device::cts_w));
 }
 
 
@@ -49,7 +45,7 @@ machine_config_constructor sv805_device::device_mconfig_additions() const
 //-------------------------------------------------
 
 sv805_device::sv805_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock) :
-	device_t(mconfig, SV805, "SV-805 RS-232 Interface", tag, owner, clock, "sv805", __FILE__),
+	device_t(mconfig, SV805, tag, owner, clock),
 	device_svi_slot_interface(mconfig, *this),
 	m_uart(*this, "uart"),
 	m_rs232(*this, "rs232")
@@ -69,7 +65,7 @@ void sv805_device::device_start()
 //  IMPLEMENTATION
 //**************************************************************************
 
-READ8_MEMBER( sv805_device::iorq_r )
+uint8_t sv805_device::iorq_r(offs_t offset)
 {
 	switch (offset)
 	{
@@ -81,13 +77,13 @@ READ8_MEMBER( sv805_device::iorq_r )
 	case 0x2d:
 	case 0x2e:
 	case 0x2f:
-		return m_uart->ins8250_r(space, offset & 0x07);
+		return m_uart->ins8250_r(offset & 0x07);
 	}
 
 	return 0xff;
 }
 
-WRITE8_MEMBER( sv805_device::iorq_w )
+void sv805_device::iorq_w(offs_t offset, uint8_t data)
 {
 	switch (offset)
 	{
@@ -99,7 +95,7 @@ WRITE8_MEMBER( sv805_device::iorq_w )
 	case 0x2d:
 	case 0x2e:
 	case 0x2f:
-		m_uart->ins8250_w(space, offset & 0x07, data);
+		m_uart->ins8250_w(offset & 0x07, data);
 	}
 }
 
