@@ -6,12 +6,11 @@
 
 **********************************************************************/
 
+#ifndef MAME_BUS_VCS_CTRL_KEYPAD_H
+#define MAME_BUS_VCS_CTRL_KEYPAD_H
+
 #pragma once
 
-#ifndef __VCS_KEYPAD__
-#define __VCS_KEYPAD__
-
-#include "emu.h"
 #include "ctrl.h"
 
 
@@ -53,7 +52,6 @@ private:
 
 
 // device type definition
-extern const device_type VCS_KEYPAD;
+DECLARE_DEVICE_TYPE(VCS_KEYPAD, vcs_keypad_device)
 
-
-#endif
+#endif // MAME_BUS_VCS_CTRL_KEYPAD_H
