@@ -9,8 +9,9 @@
 ***************************************************************************/
 
 #include "emu.h"
-#include "debugger.h"
 #include "tms32031.h"
+#include "dis32031.h"
+#include "debugger.h"
 
 
 //**************************************************************************
@@ -87,22 +88,47 @@ const int GIEFLAG   = 0x2000;
 //**************************************************************************
 
 // device type definition
-const device_type TMS32031 = &device_creator<tms32031_device>;
-const device_type TMS32032 = &device_creator<tms32032_device>;
+DEFINE_DEVICE_TYPE(TMS32030, tms32030_device, "tms32030", "Texas Instruments TMS32030")
+DEFINE_DEVICE_TYPE(TMS32031, tms32031_device, "tms32031", "Texas Instruments TMS32031")
+DEFINE_DEVICE_TYPE(TMS32032, tms32032_device, "tms32032", "Texas Instruments TMS32032")
 
+// memory map common to all 'C30 devices
+// TODO: expand to cover all the standard internal peripherals
+void tms3203x_device::common_3203x(address_map &map)
+{
+	map(0x808064, 0x808064).rw(FUNC(tms3203x_device::primary_bus_control_r), FUNC(tms3203x_device::primary_bus_control_w));
+}
 
 // internal memory maps
-static ADDRESS_MAP_START( internal_32031, AS_PROGRAM, 32, tms32031_device )
-	AM_RANGE(0x809800, 0x809fff) AM_RAM
-ADDRESS_MAP_END
+void tms32030_device::internal_32030(address_map &map)
+{
+	common_3203x(map);
 
-static ADDRESS_MAP_START( internal_32032, AS_PROGRAM, 32, tms32032_device )
-	AM_RANGE(0x87fe00, 0x87ffff) AM_RAM
-ADDRESS_MAP_END
+	map(0x809800, 0x809fff).ram();
+}
+
+void tms32031_device::internal_32031(address_map &map)
+{
+	common_3203x(map);
+
+	map(0x809800, 0x809fff).ram();
+}
+
+void tms32032_device::internal_32032(address_map &map)
+{
+	common_3203x(map);
+
+	map(0x87fe00, 0x87ffff).ram();
+}
 
 
 // ROM definitions for the internal boot loader programs
 // (Using assembled versions until the code ROMs are extracted from both DSPs)
+ROM_START( tms32030 )
+	ROM_REGION(0x4000, "tms32030", 0)
+	ROM_LOAD( "c30boot.bin", 0x0000, 0x4000, BAD_DUMP CRC(bddc2763) SHA1(96b2170ecee5bec5abaa1741bb2d3b6096ecc262))
+ROM_END
+
 ROM_START( tms32031 )
 	ROM_REGION(0x4000, "tms32031", 0)
 	ROM_LOAD( "c31boot.bin", 0x0000, 0x4000, BAD_DUMP CRC(bddc2763) SHA1(96b2170ecee5bec5abaa1741bb2d3b6096ecc262) ) // Assembled from c31boot.asm (02-07-92)
@@ -251,59 +277,52 @@ void tms3203x_device::tmsreg::from_double(double val)
 //  tms3203x_device - constructor
 //-------------------------------------------------
 
-tms3203x_device::tms3203x_device(const machine_config &mconfig, device_type type, const char *name, const char *tag, device_t *owner, uint32_t clock, uint32_t chiptype, address_map_constructor internal_map, const char *shortname, const char *source)
-	: cpu_device(mconfig, type, name, tag, owner, clock, shortname, source),
+tms3203x_device::tms3203x_device(const machine_config &mconfig, device_type type, const char *tag, device_t *owner, uint32_t clock, uint32_t chiptype, address_map_constructor internal_map)
+	: cpu_device(mconfig, type, tag, owner, clock),
 		m_program_config("program", ENDIANNESS_LITTLE, 32, 24, -2, internal_map),
 		m_chip_type(chiptype),
 		m_pc(0),
 		m_bkmask(0),
+		m_primary_bus_control(0),
 		m_irq_state(0),
 		m_delayed(false),
 		m_irq_pending(false),
 		m_is_idling(false),
 		m_icount(0),
 		m_program(nullptr),
-		m_direct(nullptr),
+		m_cache(nullptr),
 		m_mcbl_mode(false),
 		m_xf0_cb(*this),
 		m_xf1_cb(*this),
-		m_iack_cb(*this)
+		m_iack_cb(*this),
+		m_holda_cb(*this)
 {
 	// initialize remaining state
 	memset(&m_r, 0, sizeof(m_r));
 
 	// set our instruction counter
-	m_icountptr = &m_icount;
+	set_icountptr(m_icount);
 
 #if (TMS_3203X_LOG_OPCODE_USAGE)
 	memset(m_hits, 0, sizeof(m_hits));
 #endif
 }
 
+tms32030_device::tms32030_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock)
+	: tms3203x_device(mconfig, TMS32030, tag, owner, clock, CHIP_TYPE_TMS32030, address_map_constructor(FUNC(tms32030_device::internal_32030), this))
+{
+}
+
 tms32031_device::tms32031_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock)
-	: tms3203x_device(mconfig, TMS32031, "TMS32031", tag, owner, clock, CHIP_TYPE_TMS32031, ADDRESS_MAP_NAME(internal_32031), "tms32031", __FILE__)
+	: tms3203x_device(mconfig, TMS32031, tag, owner, clock, CHIP_TYPE_TMS32031, address_map_constructor(FUNC(tms32031_device::internal_32031), this))
 {
 }
 
 tms32032_device::tms32032_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock)
-	: tms3203x_device(mconfig, TMS32032, "TMS32032", tag, owner, clock, CHIP_TYPE_TMS32032, ADDRESS_MAP_NAME(internal_32032), "tms32032", __FILE__)
+	: tms3203x_device(mconfig, TMS32032, tag, owner, clock, CHIP_TYPE_TMS32032, address_map_constructor(FUNC(tms32032_device::internal_32032), this))
 {
 }
 
-
-DIRECT_UPDATE_MEMBER( tms3203x_device::direct_handler )
-{
-	// internal boot loader ROM
-	if (m_mcbl_mode && address < (0x1000 << 2))
-	{
-		direct.explicit_configure(0x000000, 0x003fff, 0x003fff, m_bootrom);
-		return (offs_t)-1;
-	}
-
-	return address;
-}
-
-
 //-------------------------------------------------
 //  ~tms3203x_device - destructor
 //-------------------------------------------------
@@ -328,6 +347,7 @@ const tiny_rom_entry *tms3203x_device::device_rom_region() const
 	switch (m_chip_type)
 	{
 		default:
+		case CHIP_TYPE_TMS32030:    return ROM_NAME( tms32030 );
 		case CHIP_TYPE_TMS32031:    return ROM_NAME( tms32031 );
 		case CHIP_TYPE_TMS32032:    return ROM_NAME( tms32032 );
 	}
@@ -339,7 +359,7 @@ const tiny_rom_entry *tms3203x_device::device_rom_region() const
 
 inline uint32_t tms3203x_device::ROPCODE(offs_t pc)
 {
-	return m_direct->read_dword(pc << 2);
+	return m_cache->read_dword(pc);
 }
 
 
@@ -349,10 +369,7 @@ inline uint32_t tms3203x_device::ROPCODE(offs_t pc)
 
 inline uint32_t tms3203x_device::RMEM(offs_t addr)
 {
-	if (m_mcbl_mode && addr < 0x1000)
-		return m_bootrom[addr];
-
-	return m_program->read_dword(addr << 2);
+	return m_program->read_dword(addr);
 }
 
 
@@ -362,7 +379,7 @@ inline uint32_t tms3203x_device::RMEM(offs_t addr)
 
 inline void tms3203x_device::WMEM(offs_t addr, uint32_t data)
 {
-	m_program->write_dword(addr << 2, data);
+	m_program->write_dword(addr, data);
 }
 
 
@@ -374,27 +391,30 @@ void tms3203x_device::device_start()
 {
 	// find address spaces
 	m_program = &space(AS_PROGRAM);
-	m_direct = &m_program->direct();
+	m_cache = m_program->cache<2, -2, ENDIANNESS_LITTLE>();
 
 	// resolve devcb handlers
 	m_xf0_cb.resolve_safe();
 	m_xf1_cb.resolve_safe();
 	m_iack_cb.resolve_safe();
+	m_holda_cb.resolve_safe();
 
 	// set up the internal boot loader ROM
-	m_bootrom = reinterpret_cast<uint32_t*>(memregion(shortname())->base());
-	m_direct->set_direct_update(direct_update_delegate(&tms3203x_device::direct_handler, this));
+	if (m_mcbl_mode)
+		m_program->install_rom(0x000000, 0x000fff, memregion(shortname())->base());
 
 	// save state
 	save_item(NAME(m_pc));
 	for (int regnum = 0; regnum < 36; regnum++)
 		save_item(NAME(m_r[regnum].i32), regnum);
 	save_item(NAME(m_bkmask));
+	save_item(NAME(m_primary_bus_control));
 	save_item(NAME(m_irq_state));
 	save_item(NAME(m_delayed));
 	save_item(NAME(m_irq_pending));
 	save_item(NAME(m_is_idling));
 	save_item(NAME(m_mcbl_mode));
+	save_item(NAME(m_hold_state));
 
 	// register our state for the debugger
 	state_add(TMS3203X_PC,      "PC",        m_pc);
@@ -457,6 +477,9 @@ void tms3203x_device::device_reset()
 	// update IF with the external interrupt state (required for boot loader operation)
 	IREG(TMR_IF) |= m_irq_state & 0x0f;
 
+	// reset peripheral registers
+	m_primary_bus_control = 0x000010f8;
+
 	// reset internal stuff
 	m_delayed = m_irq_pending = m_is_idling = false;
 }
@@ -468,9 +491,11 @@ void tms3203x_device::device_reset()
 //  the space doesn't exist
 //-------------------------------------------------
 
-const address_space_config *tms3203x_device::memory_space_config(address_spacenum spacenum) const
+device_memory_interface::space_config_vector tms3203x_device::memory_space_config() const
 {
-	return (spacenum == AS_PROGRAM) ? &m_program_config : nullptr;
+	return space_config_vector {
+		std::make_pair(AS_PROGRAM, &m_program_config)
+	};
 }
 
 
@@ -563,36 +588,13 @@ void tms3203x_device::state_string_export(const device_state_entry &entry, std::
 
 
 //-------------------------------------------------
-//  disasm_min_opcode_bytes - return the length
-//  of the shortest instruction, in bytes
-//-------------------------------------------------
-
-uint32_t tms3203x_device::disasm_min_opcode_bytes() const
-{
-	return 4;
-}
-
-
-//-------------------------------------------------
-//  disasm_max_opcode_bytes - return the length
-//  of the longest instruction, in bytes
-//-------------------------------------------------
-
-uint32_t tms3203x_device::disasm_max_opcode_bytes() const
-{
-	return 4;
-}
-
-
-//-------------------------------------------------
-//  disasm_disassemble - call the disassembly
+//  disassemble - call the disassembly
 //  helper function
 //-------------------------------------------------
 
-offs_t tms3203x_device::disasm_disassemble(std::ostream &stream, offs_t pc, const uint8_t *oprom, const uint8_t *opram, uint32_t options)
+std::unique_ptr<util::disasm_interface> tms3203x_device::create_disassembler()
 {
-	extern CPU_DISASSEMBLE( tms3203x );
-	return CPU_DISASSEMBLE_NAME(tms3203x)(this, stream, pc, oprom, opram, options);
+	return std::make_unique<tms32031_disassembler>();
 }
 
 
@@ -700,7 +702,7 @@ void tms3203x_device::check_irqs()
 //  cycles it takes for one instruction to execute
 //-------------------------------------------------
 
-uint32_t tms3203x_device::execute_min_cycles() const
+uint32_t tms3203x_device::execute_min_cycles() const noexcept
 {
 	return 1;
 }
@@ -711,7 +713,7 @@ uint32_t tms3203x_device::execute_min_cycles() const
 //  cycles it takes for one instruction to execute
 //-------------------------------------------------
 
-uint32_t tms3203x_device::execute_max_cycles() const
+uint32_t tms3203x_device::execute_max_cycles() const noexcept
 {
 	return 4;
 }
@@ -722,9 +724,9 @@ uint32_t tms3203x_device::execute_max_cycles() const
 //  input/interrupt lines
 //-------------------------------------------------
 
-uint32_t tms3203x_device::execute_input_lines() const
+uint32_t tms3203x_device::execute_input_lines() const noexcept
 {
-	return (m_chip_type == CHIP_TYPE_TMS32032) ? 13 : 12;
+	return 14;
 }
 
 
@@ -734,15 +736,45 @@ uint32_t tms3203x_device::execute_input_lines() const
 
 void tms3203x_device::execute_set_input(int inputnum, int state)
 {
-	// ignore anything out of range
-	if (inputnum >= 13)
-		return;
-
 	if (inputnum == TMS3203X_MCBL)
 	{
 		// switch between microcomputer/boot loader and microprocessor modes
+		bool old_mode = m_mcbl_mode;
 		m_mcbl_mode = (state == ASSERT_LINE);
-		m_direct->force_update();
+		if (m_mcbl_mode != old_mode)
+		{
+			if (m_mcbl_mode)
+				m_program->install_rom(0x000000, 0x000fff, memregion(shortname())->base());
+			else
+				m_program->unmap_read(0x000000, 0x000fff);
+		}
+		return;
+	}
+
+	if (inputnum == TMS3203X_HOLD)
+	{
+		m_hold_state = (state == ASSERT_LINE);
+
+		// FIXME: "there is a minimum of one cycle delay from the time when
+		// the processor recognises /HOLD = 0 until /HOLDA = 0"
+		if (m_hold_state)
+		{
+			// assert hold acknowledge if external hold enabled
+			if (!(m_primary_bus_control & NOHOLD))
+			{
+				m_primary_bus_control |= HOLDST;
+				m_holda_cb(ASSERT_LINE);
+			}
+		}
+		else
+		{
+			// clear hold acknowledge if port is held externally
+			if ((m_primary_bus_control & HOLDST) && !(m_primary_bus_control & HIZ))
+			{
+				m_primary_bus_control &= ~HOLDST;
+				m_holda_cb(CLEAR_LINE);
+			}
+		}
 		return;
 	}
 
@@ -759,7 +791,7 @@ void tms3203x_device::execute_set_input(int inputnum, int state)
 	// external interrupts are level-sensitive on the '31 and can be
 	// configured as such on the '32; in that case, if the external
 	// signal is high, we need to update the value in IF accordingly
-	if (m_chip_type == CHIP_TYPE_TMS32031 || (IREG(TMR_ST) & 0x4000) == 0)
+	if (m_chip_type != CHIP_TYPE_TMS32032 || (IREG(TMR_ST) & 0x4000) == 0)
 		IREG(TMR_IF) |= m_irq_state & 0x0f;
 }
 
@@ -837,12 +869,36 @@ void tms3203x_device::execute_run()
 				continue;
 			}
 
-			debugger_instruction_hook(this, m_pc);
+			debugger_instruction_hook(m_pc);
 			execute_one();
 		}
 	}
 }
 
+// internal peripherals
+WRITE32_MEMBER(tms3203x_device::primary_bus_control_w)
+{
+	// change in internal hold state
+	if ((m_primary_bus_control ^ data) & HIZ)
+	{
+		if (m_primary_bus_control & HOLDST)
+			m_primary_bus_control &= ~HOLDST;
+		else
+			m_primary_bus_control |= HOLDST;
+		m_holda_cb(data & HIZ ? ASSERT_LINE : CLEAR_LINE);
+	}
+
+	// enable of external hold with hold pending
+	if ((m_primary_bus_control & NOHOLD) && !(data & NOHOLD) && m_hold_state)
+	{
+		m_primary_bus_control |= HOLDST;
+		m_holda_cb(ASSERT_LINE);
+	}
+
+	// update register
+	m_primary_bus_control = (m_primary_bus_control & ~(mem_mask | WMASK)) | (data & mem_mask & WMASK);
+}
+
 
 //**************************************************************************
 //  CORE OPCODES
