@@ -1,8 +1,9 @@
 // license:BSD-3-Clause
 // copyright-holders:Wilbert Pol,Bryan McPhail
-#ifndef __V30MZ_H__
-#define __V30MZ_H__
+#ifndef MAME_CPU_V32MZ_V30MZ_H
+#define MAME_CPU_V32MZ_V30MZ_H
 
+#include "cpu/nec/necdasm.h"
 
 struct nec_config
 {
@@ -20,9 +21,9 @@ enum
 
 /////////////////////////////////////////////////////////////////
 
-extern const device_type V30MZ;
+DECLARE_DEVICE_TYPE(V30MZ, v30mz_cpu_device)
 
-class v30mz_cpu_device : public cpu_device
+class v30mz_cpu_device : public cpu_device, public nec_disassembler::config
 {
 public:
 	// construction/destruction
@@ -34,22 +35,22 @@ protected:
 	virtual void device_reset() override;
 
 	// device_execute_interface overrides
-	virtual uint32_t execute_min_cycles() const override { return 1; }
-	virtual uint32_t execute_max_cycles() const override { return 80; }
-	virtual uint32_t execute_input_lines() const override { return 1; }
+	virtual uint32_t execute_min_cycles() const noexcept override { return 1; }
+	virtual uint32_t execute_max_cycles() const noexcept override { return 80; }
+	virtual uint32_t execute_input_lines() const noexcept override { return 1; }
+	virtual bool execute_input_edge_triggered(int inputnum) const noexcept override { return inputnum == INPUT_LINE_NMI; }
 	virtual void execute_run() override;
 	virtual void execute_set_input(int inputnum, int state) override;
 
 	// device_memory_interface overrides
-	virtual const address_space_config *memory_space_config(address_spacenum spacenum = AS_0) const override { return (spacenum == AS_PROGRAM) ? &m_program_config : ( (spacenum == AS_IO) ? &m_io_config : nullptr ); }
+	virtual space_config_vector memory_space_config() const override;
 
 	// device_state_interface overrides
 	virtual void state_string_export(const device_state_entry &entry, std::string &str) const override;
 
 	// device_disasm_interface overrides
-	virtual uint32_t disasm_min_opcode_bytes() const override { return 1; }
-	virtual uint32_t disasm_max_opcode_bytes() const override { return 7; }
-	virtual offs_t disasm_disassemble(std::ostream &stream, offs_t pc, const uint8_t *oprom, const uint8_t *opram, uint32_t options) override;
+	virtual std::unique_ptr<util::disasm_interface> create_disassembler() override;
+	virtual int get_mode() const override { return 1; };
 
 	void interrupt(int int_num);
 
@@ -166,7 +167,6 @@ protected:
 	inline void ADJ4(int8_t param1, int8_t param2);
 	inline void ADJB(int8_t param1, int8_t param2);
 
-protected:
 	address_space_config m_program_config;
 	address_space_config m_io_config;
 
@@ -190,7 +190,7 @@ protected:
 	uint8_t   m_fire_trap;
 
 	address_space *m_program;
-	direct_read_data *m_direct;
+	memory_access_cache<0, 0, ENDIANNESS_LITTLE> *m_cache;
 	address_space *m_io;
 	int m_icount;
 
@@ -222,5 +222,4 @@ protected:
 	} m_Mod_RM;
 };
 
-
-#endif /* __V30MZ_H__ */
+#endif // MAME_CPU_V32MZ_V30MZ_H
