@@ -37,6 +37,7 @@
 
 *********************************************************************/
 
+#include "emu.h"
 #include "applefdc.h"
 
 
@@ -105,8 +106,8 @@ enum
 //  ctor
 //-------------------------------------------------
 
-applefdc_base_device::applefdc_base_device(applefdc_base_device::applefdc_t fdc_type, const machine_config &mconfig, device_type type, const char *name, const char *tag, device_t *owner, uint32_t clock, const char *shortname, const char *source)
-	: device_t(mconfig, type, name, tag, owner, clock, shortname, source),
+applefdc_base_device::applefdc_base_device(applefdc_base_device::applefdc_t fdc_type, const machine_config &mconfig, device_type type, const char *tag, device_t *owner, uint32_t clock)
+	: device_t(mconfig, type, tag, owner, clock),
 		m_type(fdc_type),
 		m_interface(nullptr)
 {
@@ -441,7 +442,7 @@ void applefdc_base_device::iwm_access(int offset)
 //  read - reads a byte from the FDC
 //-------------------------------------------------
 
-uint8_t applefdc_base_device::read(uint8_t offset)
+uint8_t applefdc_base_device::read(offs_t offset)
 {
 	const applefdc_interface *intf = get_interface();
 	uint8_t result = 0;
@@ -504,7 +505,7 @@ uint8_t applefdc_base_device::read(uint8_t offset)
 //  write - writes a byte to the FDC
 //-------------------------------------------------
 
-void applefdc_base_device::write(uint8_t offset, uint8_t data)
+void applefdc_base_device::write(offs_t offset, uint8_t data)
 {
 	const applefdc_interface *intf = get_interface();
 
@@ -564,10 +565,10 @@ uint8_t applefdc_base_device::get_lines()
     APPLE FDC - Used on Apple II
 ***************************************************************************/
 
-const device_type APPLEFDC = &device_creator<applefdc_device>;
+DEFINE_DEVICE_TYPE(APPLEFDC, applefdc_device, "apple_fdc", "Apple FDC")
 
 applefdc_device::applefdc_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock)
-	: applefdc_base_device(APPLEFDC_APPLE2, mconfig, APPLEFDC, "Apple FDC", tag, owner, clock, "apple_fdc", __FILE__)
+	: applefdc_base_device(APPLEFDC_APPLE2, mconfig, APPLEFDC, tag, owner, clock)
 {
 }
 
@@ -577,9 +578,9 @@ applefdc_device::applefdc_device(const machine_config &mconfig, const char *tag,
     IWM - Used on early Macs
 ***************************************************************************/
 
-const device_type IWM = &device_creator<iwm_device>;
+DEFINE_DEVICE_TYPE(IWM, iwm_device, "iwm", "Apple IWM (Integrated Woz Machine)")
 
 iwm_device::iwm_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock)
-	: applefdc_base_device(APPLEFDC_IWM, mconfig, IWM, "Apple IWM (Integrated Woz Machine)", tag, owner, clock, "iwm", __FILE__)
+	: applefdc_base_device(APPLEFDC_IWM, mconfig, IWM, tag, owner, clock)
 {
 }
