@@ -608,7 +608,7 @@ WRITE_LINE_MEMBER (fga002_device::lirq5_w) { LOGINT("%s\n", FUNCNAME); lirq_w( F
 WRITE_LINE_MEMBER (fga002_device::lirq6_w) { LOGINT("%s\n", FUNCNAME); lirq_w( FGA_ISLOCAL6, INT_LOCAL6, FGA_ICRLOCAL6, state ); }
 WRITE_LINE_MEMBER (fga002_device::lirq7_w) { LOGINT("%s\n", FUNCNAME); lirq_w( FGA_ISLOCAL7, INT_LOCAL7, FGA_ICRLOCAL7, state ); }
 
-WRITE8_MEMBER (fga002_device::write){
+void fga002_device::write(offs_t offset, uint8_t data){
 	LOG("%s[%04x] <- %02x    - ", FUNCNAME, offset, data);
 	LOGSETUP(" * %s Reg %04x <- %02x\n", tag(), offset, data);
 	switch(offset)
@@ -718,7 +718,7 @@ WRITE8_MEMBER (fga002_device::write){
 	}
 }
 
-READ8_MEMBER (fga002_device::read){
+uint8_t fga002_device::read(offs_t offset){
 	uint8_t ret = 0;
 
 	LOG("%s[%04x]      ", FUNCNAME, offset);
