@@ -484,7 +484,7 @@ void pioneer_pr8210_device::player_overlay(bitmap_yuy16 &bitmap)
 //  Pioneer PIA
 //-------------------------------------------------
 
-READ8_MEMBER( pioneer_pr8210_device::i8049_pia_r )
+uint8_t pioneer_pr8210_device::i8049_pia_r(offs_t offset)
 {
 	uint8_t result = 0xff;
 	switch (offset)
@@ -532,7 +532,7 @@ READ8_MEMBER( pioneer_pr8210_device::i8049_pia_r )
 //  Pioneer PIA
 //-------------------------------------------------
 
-WRITE8_MEMBER( pioneer_pr8210_device::i8049_pia_w )
+void pioneer_pr8210_device::i8049_pia_w(offs_t offset, uint8_t data)
 {
 	uint8_t value;
 	switch (offset)
@@ -603,7 +603,7 @@ WRITE8_MEMBER( pioneer_pr8210_device::i8049_pia_w )
 //  input, which is enabled via the PIA above
 //-------------------------------------------------
 
-READ8_MEMBER( pioneer_pr8210_device::i8049_bus_r )
+uint8_t pioneer_pr8210_device::i8049_bus_r()
 {
 	/*
 	   $80 = n/c
@@ -647,7 +647,7 @@ READ8_MEMBER( pioneer_pr8210_device::i8049_bus_r )
 //  port #1
 //-------------------------------------------------
 
-WRITE8_MEMBER( pioneer_pr8210_device::i8049_port1_w )
+void pioneer_pr8210_device::i8049_port1_w(uint8_t data)
 {
 	/*
 	   $80 = (out) SCAN C (F/R)
@@ -704,7 +704,7 @@ WRITE8_MEMBER( pioneer_pr8210_device::i8049_port1_w )
 //  port #2
 //-------------------------------------------------
 
-WRITE8_MEMBER( pioneer_pr8210_device::i8049_port2_w )
+void pioneer_pr8210_device::i8049_port2_w(uint8_t data)
 {
 	/*
 	   $80 = (out) /CS on PIA
@@ -738,7 +738,7 @@ WRITE8_MEMBER( pioneer_pr8210_device::i8049_port2_w )
 //  T0 input (connected to VSYNC)
 //-------------------------------------------------
 
-READ_LINE_MEMBER( pioneer_pr8210_device::i8049_t0_r )
+int pioneer_pr8210_device::i8049_t0_r()
 {
 	// returns VSYNC state
 	return !m_vsync;
@@ -750,7 +750,7 @@ READ_LINE_MEMBER( pioneer_pr8210_device::i8049_t0_r )
 //  T1 input (pulled high)
 //-------------------------------------------------
 
-READ_LINE_MEMBER( pioneer_pr8210_device::i8049_t1_r )
+int pioneer_pr8210_device::i8049_t1_r()
 {
 	return 1;
 }
@@ -1041,7 +1041,7 @@ void simutrek_special_device::device_add_mconfig(machine_config &config)
 //  port #2
 //-------------------------------------------------
 
-READ8_MEMBER( simutrek_special_device::i8748_port2_r )
+uint8_t simutrek_special_device::i8748_port2_r()
 {
 	// bit $80 is the pr8210 video squelch
 	return (m_i8049_port1 & 0x20) ? 0x00 : 0x80;
@@ -1053,7 +1053,7 @@ READ8_MEMBER( simutrek_special_device::i8748_port2_r )
 //  port #2
 //-------------------------------------------------
 
-WRITE8_MEMBER( simutrek_special_device::i8748_port2_w )
+void simutrek_special_device::i8748_port2_w(uint8_t data)
 {
 	// update stat
 	uint8_t prev = m_i8748_port2;
@@ -1088,7 +1088,7 @@ WRITE8_MEMBER( simutrek_special_device::i8748_port2_w )
 //  i8748_data_r - handle external 8748 data reads
 //-------------------------------------------------
 
-READ8_MEMBER( simutrek_special_device::i8748_data_r )
+uint8_t simutrek_special_device::i8748_data_r()
 {
 	// acknowledge the read and clear the data ready flag
 	m_data_ready = false;
@@ -1101,7 +1101,7 @@ READ8_MEMBER( simutrek_special_device::i8748_data_r )
 //  T0 input
 //-------------------------------------------------
 
-READ_LINE_MEMBER( simutrek_special_device::i8748_t0_r )
+int simutrek_special_device::i8748_t0_r()
 {
 	// return 1 if data is waiting from main CPU
 	return m_data_ready;
