@@ -45,6 +45,7 @@ DEFINE_DEVICE_TYPE(UPD765A,        upd765a_device,        "upd765a",        "NEC
 DEFINE_DEVICE_TYPE(UPD765B,        upd765b_device,        "upd765b",        "NEC uPD765B FDC")
 DEFINE_DEVICE_TYPE(I8272A,         i8272a_device,         "i8272a",         "Intel 8272A FDC")
 DEFINE_DEVICE_TYPE(UPD72065,       upd72065_device,       "upd72065",       "NEC uPD72065 FDC")
+DEFINE_DEVICE_TYPE(UPD72067,       upd72067_device,       "upd72067",       "NEC uPD72067 FDC")
 DEFINE_DEVICE_TYPE(UPD72069,       upd72069_device,       "upd72069",       "NEC uPD72069 FDC")
 DEFINE_DEVICE_TYPE(I82072,         i82072_device,         "i82072",         "Intel 82072 FDC")
 DEFINE_DEVICE_TYPE(SMC37C78,       smc37c78_device,       "smc37c78",       "SMC FDC73C78 FDC")
@@ -141,6 +142,9 @@ void pc8477a_device::map(address_map &map)
 
 void wd37c65c_device::map(address_map &map)
 {
+	// NOTE: this map only covers registers defined by CS.
+	// LDOR and LDCR must be mapped separately, since their addresses are
+	// defined only by external decoding circuits. LDIR (optional) is also separate.
 	map(0x0, 0x0).r(FUNC(wd37c65c_device::msr_r));
 	map(0x1, 0x1).rw(FUNC(wd37c65c_device::fifo_r), FUNC(wd37c65c_device::fifo_w));
 }
@@ -166,7 +170,7 @@ void tc8566af_device::map(address_map &map)
 constexpr int upd765_family_device::rates[4];
 
 upd765_family_device::upd765_family_device(const machine_config &mconfig, device_type type, const char *tag, device_t *owner, uint32_t clock) :
-	pc_fdc_interface(mconfig, type, tag, owner, clock),
+	device_t(mconfig, type, tag, owner, clock),
 	ready_connected(true),
 	ready_polled(true),
 	select_connected(true),
@@ -2656,6 +2660,14 @@ upd72065_device::upd72065_device(const machine_config &mconfig, device_type type
 	dor_reset = 0x0c;
 }
 
+upd72067_device::upd72067_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock) : upd72065_device(mconfig, UPD72067, tag, owner, clock)
+{
+	ready_polled = true;
+	ready_connected = true;
+	select_connected = true;
+	select_multiplexed = false;
+}
+
 upd72069_device::upd72069_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock) : upd72065_device(mconfig, UPD72069, tag, owner, clock)
 {
 	ready_polled = true;
@@ -3038,3 +3050,38 @@ void upd72065_device::auxcmd_w(uint8_t data)
 		break;
 	}
 }
+
+void upd72067_device::auxcmd_w(uint8_t data)
+{
+	/*
+	 * Auxiliary commands:
+	 *
+	 *   ???? ????  start clock
+	 *   0011 0011  enable external mode
+	 *   0x00 1011  control internal mode
+	 *   xxxx 1110  enable motors
+	 *   010x 1111  select IBM or ECMA/ISO format
+	 *
+	 * The bare minimum needed to satisfy the news_r3k diagnostic has been
+	 * implemented here.
+	 */
+	switch(data & 0x0f) {
+	case 0x0e:
+		// motor on/off - no idea about timeout
+		for(unsigned i = 0; i < 4; i++)
+			if(flopi[i].dev)
+				flopi[i].dev->mon_w(!BIT(data, i + 4));
+		// fall through
+	case 0x03: // enable external mode
+	case 0x0b: // control internal mode
+	case 0x0f: // select format
+		// report a successful status
+		main_phase = PHASE_RESULT;
+		result[0] = ST0_UNK;
+		result_pos = 1;
+		break;
+	default:
+		upd72065_device::auxcmd_w(data);
+		break;
+	}
+}
