@@ -313,7 +313,7 @@ std::string machine_info::game_info_string() const
 		if (!exectags.insert(exec.device().tag()).second)
 			continue;
 		// get cpu specific clock that takes internal multiplier/dividers into account
-		int clock = exec.device().clock();
+		u32 clock = exec.device().clock();
 
 		// count how many identical CPUs we have
 		int count = 1;
@@ -325,16 +325,23 @@ std::string machine_info::game_info_string() const
 					count++;
 		}
 
-		// if more than one, prepend a #x in front of the CPU name
-		// display clock in kHz or MHz
+		std::string hz(std::to_string(clock));
+		int d = (clock >= 1'000'000'000) ? 9 : (clock >= 1'000'000) ? 6 : (clock >= 1000) ? 3 : 0;
+		if (d > 0)
+		{
+			size_t dpos = hz.length() - d;
+			hz.insert(dpos, ".");
+			size_t last = hz.find_last_not_of('0');
+			hz = hz.substr(0, last + (last != dpos ? 1 : 0));
+		}
+
+		// if more than one, prepend a #x in front of the CPU name and display clock
 		util::stream_format(buf,
-				(count > 1) ? "%1$d" UTF8_MULTIPLY "%2$s %3$d.%4$0*5$d%6$s\n" : "%2$s %3$d.%4$0*5$d%6$s\n",
-				count,
-				name,
-				(clock >= 1000000) ? (clock / 1000000) : (clock / 1000),
-				(clock >= 1000000) ? (clock % 1000000) : (clock % 1000),
-				(clock >= 1000000) ? 6 : 3,
-				(clock >= 1000000) ? _("MHz") : _("kHz"));
+				(count > 1)
+					? ((clock != 0) ? "%1$d" UTF8_MULTIPLY "%2$s %3$s" UTF8_NBSP "%4$s\n" : "%1$d" UTF8_MULTIPLY "%2$s\n")
+					: ((clock != 0) ? "%2$s %3$s" UTF8_NBSP "%4$s\n" : "%2$s\n"),
+				count, name, hz,
+				(d == 9) ? _("GHz") : (d == 6) ? _("MHz") : (d == 3) ? _("kHz") : _("Hz"));
 	}
 
 	// loop over all sound chips
@@ -360,19 +367,24 @@ std::string machine_info::game_info_string() const
 					count++;
 		}
 
-		// if more than one, prepend a #x in front of the CPU name
-		// display clock in kHz or MHz
-		int clock = sound.device().clock();
+		const u32 clock = sound.device().clock();
+		std::string hz(std::to_string(clock));
+		int d = (clock >= 1'000'000'000) ? 9 : (clock >= 1'000'000) ? 6 : (clock >= 1000) ? 3 : 0;
+		if (d > 0)
+		{
+			size_t dpos = hz.length() - d;
+			hz.insert(dpos, ".");
+			size_t last = hz.find_last_not_of('0');
+			hz = hz.substr(0, last + (last != dpos ? 1 : 0));
+		}
+
+		// if more than one, prepend a #x in front of the soundchip name and display clock
 		util::stream_format(buf,
 				(count > 1)
-					? ((clock != 0) ? "%1$d" UTF8_MULTIPLY "%2$s %3$d.%4$0*5$d%6$s\n" : "%1$d" UTF8_MULTIPLY "%2$s\n")
-					: ((clock != 0) ? "%2$s %3$d.%4$0*5$d%6$s\n" : "%2$s\n"),
-				count,
-				sound.device().name(),
-				(clock >= 1000000) ? (clock / 1000000) : (clock / 1000),
-				(clock >= 1000000) ? (clock % 1000000) : (clock % 1000),
-				(clock >= 1000000) ? 6 : 3,
-				(clock >= 1000000) ? _("MHz") : _("kHz"));
+					? ((clock != 0) ? "%1$d" UTF8_MULTIPLY "%2$s %3$s" UTF8_NBSP "%4$s\n" : "%1$d" UTF8_MULTIPLY "%2$s\n")
+					: ((clock != 0) ? "%2$s %3$s" UTF8_NBSP "%4$s\n" : "%2$s\n"),
+				count, sound.device().name(), hz,
+				(d == 9) ? _("GHz") : (d == 6) ? _("MHz") : (d == 3) ? _("kHz") : _("Hz"));
 	}
 
 	// display screen information
@@ -390,11 +402,16 @@ std::string machine_info::game_info_string() const
 				detail = _("Vector");
 			else
 			{
+				std::string hz(std::to_string(float(screen.frame_period().as_hz())));
+				size_t last = hz.find_last_not_of('0');
+				size_t dpos = hz.find_last_of('.');
+				hz = hz.substr(0, last + (last != dpos ? 1 : 0));
+
 				const rectangle &visarea = screen.visible_area();
-				detail = string_format("%d " UTF8_MULTIPLY " %d (%s) %f" UTF8_NBSP "Hz",
+				detail = string_format("%d " UTF8_MULTIPLY " %d (%s) %s" UTF8_NBSP "Hz",
 						visarea.width(), visarea.height(),
 						(screen.orientation() & ORIENTATION_SWAP_XY) ? "V" : "H",
-						screen.frame_period().as_hz());
+						hz);
 			}
 
 			util::stream_format(buf,
