@@ -8,6 +8,14 @@
 
 *********************************************************************/
 
+#include "flopimg.h"
+#include "imageutl.h"
+
+#include "emucore.h" // emu_fatalerror
+#include "osdcore.h"
+#include "ioprocs.h"
+#include "pool.h"
+
 #include <cstdlib>
 #include <cstring>
 #include <cstdio>
@@ -15,13 +23,6 @@
 #include <climits>
 #include <cassert>
 
-#include "emu.h" // emu_fatalerror
-#include "osdcore.h"
-#include "ioprocs.h"
-#include "flopimg.h"
-#include "pool.h"
-#include "imageutl.h"
-
 #define TRACK_LOADED        0x01
 #define TRACK_DIRTY         0x02
 
