@@ -99,7 +99,7 @@ namespace netlist
 
 	NETLIB_RESET(2102A)
 	{
-		m_RAM.setTo(&m_ram[0]);
+		m_RAM.set(&m_ram[0]);
 		for (std::size_t i=0; i<128; i++)
 			m_ram[i] = 0;
 	}
