@@ -28,13 +28,13 @@ namespace netlist
 		const std::vector<std::pair<pstring, pstring>> power_syms = { {"VCC", "VEE"}, {"VCC", "GND"}, {"VDD", "VSS"}};
 
 		bool f = false;
-		for (auto & pwr_sym : power_syms)
+		for (const auto & pwr_sym : power_syms)
 		{
 			pstring devname = inout_proxied->device().name();
 
-			auto tp_ct(anetlist.setup().find_terminal(devname + "." + pwr_sym.first,
+			auto *tp_ct(anetlist.setup().find_terminal(devname + "." + pwr_sym.first,
 					/*detail::terminal_type::INPUT,*/ false));
-			auto tp_cn(anetlist.setup().find_terminal(devname + "." + pwr_sym.second,
+			auto *tp_cn(anetlist.setup().find_terminal(devname + "." + pwr_sym.second,
 				/*detail::terminal_type::INPUT,*/ false));
 			if (tp_ct && tp_cn)
 			{
@@ -43,8 +43,8 @@ namespace netlist
 				if (tp_cn && !tp_cn->is_analog())
 					throw nl_exception(plib::pfmt("Not an analog terminal: {1}")(tp_cn->name()));
 
-				auto tp_t = static_cast<analog_t* >(tp_ct);
-				auto tn_t = static_cast<analog_t *>(tp_cn);
+				auto *tp_t = static_cast<analog_t* >(tp_ct);
+				auto *tn_t = static_cast<analog_t *>(tp_cn);
 				if (f && (tp_t != nullptr && tn_t != nullptr))
 					log().warning(MI_MULTIPLE_POWER_TERMINALS_ON_DEVICE(inout_proxied->device().name(),
 						m_tp->name(), m_tn->name(),
@@ -117,7 +117,6 @@ namespace netlist
 	, m_RP(*this, "RP")
 	, m_RN(*this, "RN")
 	, m_last_state(*this, "m_last_var", -1)
-	, m_is_timestep(false)
 	{
 		register_subalias("Q", m_RN.m_P);
 
@@ -145,7 +144,6 @@ namespace netlist
 		m_last_state = -1;
 		m_RN.reset();
 		m_RP.reset();
-		m_is_timestep = m_RN.m_P.net().solver()->has_timestep_devices();
 		m_RN.set_G_V_I(plib::reciprocal(logic_family()->R_low()),
 				logic_family()->low_offset_V(), nlconst::zero());
 		m_RP.set_G_V_I(G_OFF,
@@ -158,28 +156,27 @@ namespace netlist
 		const auto state = static_cast<int>(m_I());
 		if (state != m_last_state)
 		{
-			// We only need to update the net first if this is a time stepping net
-			if (m_is_timestep)
+			// RN, RP are connected ...
+			m_RN.change_state([this, &state]()
 			{
-				m_RN.update(); // RN, RP are connected ...
-			}
-			if (state)
-			{
-				m_RN.set_G_V_I(G_OFF,
-					nlconst::zero(),
-					nlconst::zero());
-				m_RP.set_G_V_I(plib::reciprocal(logic_family()->R_high()),
-						logic_family()->high_offset_V(), nlconst::zero());
-			}
-			else
-			{
-				m_RN.set_G_V_I(plib::reciprocal(logic_family()->R_low()),
-						logic_family()->low_offset_V(), nlconst::zero());
-				m_RP.set_G_V_I(G_OFF,
-					nlconst::zero(),
-					nlconst::zero());
-			}
-			m_RN.solve_later(); // RN, RP are connected ...
+				if (state)
+				{
+
+					m_RN.set_G_V_I(G_OFF,
+						nlconst::zero(),
+						nlconst::zero());
+					m_RP.set_G_V_I(plib::reciprocal(logic_family()->R_high()),
+							logic_family()->high_offset_V(), nlconst::zero());
+				}
+				else
+				{
+					m_RN.set_G_V_I(plib::reciprocal(logic_family()->R_low()),
+							logic_family()->low_offset_V(), nlconst::zero());
+					m_RP.set_G_V_I(G_OFF,
+						nlconst::zero(),
+						nlconst::zero());
+				}
+			});
 			m_last_state = state;
 		}
 	}
