@@ -14,6 +14,7 @@
 
 #include "nl_config.h"
 #include "plib/pchrono.h"
+#include "plib/pdynlib.h"
 #include "plib/pfmtlog.h"
 #include "plib/pmempool.h"
 #include "plib/pstate.h"
@@ -51,12 +52,20 @@ namespace netlist
 		callbacks_t() = default;
 		virtual ~callbacks_t() = default;
 
-		COPYASSIGNMOVE(callbacks_t, default)
+		PCOPYASSIGNMOVE(callbacks_t, default)
 
 		/// \brief logging callback.
 		///
 		virtual void vlog(const plib::plog_level &l, const pstring &ls) const noexcept = 0;
 
+		/// \brief provide library with static solver implementations.
+		///
+		/// By default no static solvers are provided since these are
+		/// determined by the specific use case. It is up to the implementor
+		/// of a callbacks_t implementation to optionally provide such a collection
+		/// of symbols.
+		///
+		virtual plib::unique_ptr<plib::dynlib_base> static_solver_lib() const;
 	};
 
 	using log_type =  plib::plog_base<callbacks_t, NL_DEBUG>;
@@ -122,9 +131,9 @@ namespace netlist
 namespace plib {
 
 	template<>
-	inline void state_manager_t::save_item(const void *owner, netlist::netlist_time &nlt, const pstring &stname)
+	inline void state_manager_t::save_item(const void *owner, netlist::netlist_time &state, const pstring &stname)
 	{
-		save_state_ptr(owner, stname, datatype_t(sizeof(netlist::netlist_time::internal_type), true, false), 1, nlt.get_internaltype_ptr());
+		save_state_ptr(owner, stname, datatype_t(sizeof(netlist::netlist_time::internal_type), true, false), 1, state.get_internaltype_ptr());
 	}
 } // namespace plib
 
