@@ -35,19 +35,15 @@ namespace plib {
 	int app::main_utfX(int argc, char **argv)
 	{
 		auto r = this->parse(argc, argv);
-		int ret = 0;
 
 		if (r != argc)
 		{
 			this->perr("Error parsing {}\n", argv[r]);
-			//FIXME: usage_short
-			this->perr(this->usage());
-			ret = 1;
+			this->perr(this->usage_short());
+			return 1;
 		}
-		else
-			ret = this->execute();
 
-		return ret;
+		return this->execute();
 	}
 
 #ifdef _WIN32
