@@ -17,29 +17,29 @@
 namespace plib
 {
 
-
 	template<typename T, typename A = aligned_allocator<T>>
 	class pmatrix2d
 	{
 	public:
+		using size_type = std::size_t;
 		using value_type = T;
 		using allocator_type = A;
 
-		static constexpr const std::size_t align_size = align_traits<A>::align_size;
-		static constexpr const std::size_t stride_size = align_traits<A>::stride_size;
-		pmatrix2d()
+		static constexpr const size_type align_size = align_traits<A>::align_size;
+		static constexpr const size_type stride_size = align_traits<A>::stride_size;
+		pmatrix2d() noexcept
 		: m_N(0), m_M(0), m_stride(8), m_v()
 		{
 		}
 
-		pmatrix2d(std::size_t N, std::size_t M)
+		pmatrix2d(size_type N, size_type M)
 		: m_N(N), m_M(M), m_v()
 		{
 			m_stride = ((M + stride_size-1) / stride_size) * stride_size;
 			m_v.resize(N * m_stride);
 		}
 
-		void resize(std::size_t N, std::size_t M)
+		void resize(size_type N, size_type M)
 		{
 			m_N = N;
 			m_M = M;
@@ -47,31 +47,45 @@ namespace plib
 			m_v.resize(N * m_stride);
 		}
 
-		C14CONSTEXPR T * operator[] (std::size_t row) noexcept
+		C14CONSTEXPR T * operator[] (size_type row) noexcept
 		{
 			return assume_aligned_ptr<T, align_size>(&m_v[m_stride * row]);
 		}
 
-		constexpr const T * operator[] (std::size_t row) const noexcept
+		constexpr const T * operator[] (size_type row) const noexcept
 		{
 			return assume_aligned_ptr<T, align_size>(&m_v[m_stride * row]);
 		}
 
-		T & operator()(std::size_t r, std::size_t c) noexcept
+		T & operator()(size_type r, size_type c) noexcept
 		{
 			return (*this)[r][c];
 		}
 
-		const T & operator()(std::size_t r, std::size_t c) const noexcept
+		const T & operator()(size_type r, size_type c) const noexcept
 		{
 			return (*this)[r][c];
 		}
 
+		T * data() noexcept
+		{
+			return m_v.data();
+		}
+
+		const T * data() const noexcept
+		{
+			return m_v.data();
+		}
+
+		size_type didx(size_type r, size_type c) const noexcept
+		{
+			return m_stride * r + c;
+		}
 	private:
 
-		std::size_t m_N;
-		std::size_t m_M;
-		std::size_t m_stride;
+		size_type m_N;
+		size_type m_M;
+		size_type m_stride;
 
 		std::vector<T, A> m_v;
 	};
