@@ -14,67 +14,75 @@
 #include <string>
 #include <type_traits>
 
+#if (PUSE_FLOAT128)
+#include <quadmath.h>
+#endif
+
 // noexcept on move operator -> issue with macosx clang
-#define COPYASSIGNMOVE(name, def)  \
+#define PCOPYASSIGNMOVE(name, def)  \
 		name(const name &) = def; \
 		name(name &&) noexcept = def; \
 		name &operator=(const name &) = def; \
 		name &operator=(name &&) noexcept = def;
 
-#define COPYASSIGN(name, def)  \
+#define PCOPYASSIGN(name, def)  \
 		name(const name &) = def; \
 		name &operator=(const name &) = def; \
 
+#define PMOVEASSIGN(name, def)  \
+		name(name &&) noexcept = def; \
+		name &operator=(name &&) noexcept = def;
+
 namespace plib
 {
 	template<typename T> struct is_integral : public std::is_integral<T> { };
+	template<typename T> struct is_signed : public std::is_signed<T> { };
+	template<typename T> struct is_unsigned : public std::is_unsigned<T> { };
 	template<typename T> struct numeric_limits : public std::numeric_limits<T> { };
 
 	// 128 bit support at least on GCC is not fully supported
 #if PHAS_INT128
 	template<> struct is_integral<UINT128> { static constexpr bool value = true; };
 	template<> struct is_integral<INT128> { static constexpr bool value = true; };
+
+	template<> struct is_signed<UINT128> { static constexpr bool value = false; };
+	template<> struct is_signed<INT128> { static constexpr bool value = true; };
+
+	template<> struct is_unsigned<UINT128> { static constexpr bool value = true; };
+	template<> struct is_unsigned<INT128> { static constexpr bool value = false; };
+
 	template<> struct numeric_limits<UINT128>
 	{
 		static constexpr UINT128 max() noexcept
 		{
-			return ~((UINT128)0);
+			return ~(static_cast<UINT128>(0));
 		}
 	};
 	template<> struct numeric_limits<INT128>
 	{
 		static constexpr INT128 max() noexcept
 		{
-			return (~((UINT128)0)) >> 1;
+			return (~static_cast<UINT128>(0)) >> 1;
 		}
 	};
 #endif
 
-	//============================================================
-	// prevent implicit copying
-	//============================================================
+	template<typename T> struct is_floating_point : public std::is_floating_point<T> { };
 
-	struct nocopyassignmove
+#if PUSE_FLOAT128
+	template<> struct is_floating_point<FLOAT128> { static constexpr bool value = true; };
+	template<> struct numeric_limits<FLOAT128>
 	{
-		nocopyassignmove(const nocopyassignmove &) = delete;
-		nocopyassignmove(nocopyassignmove &&) noexcept = delete;
-		nocopyassignmove &operator=(const nocopyassignmove &) = delete;
-		nocopyassignmove &operator=(nocopyassignmove &&) noexcept = delete;
-	protected:
-		nocopyassignmove() = default;
-		~nocopyassignmove() noexcept = default;
-	};
-
-	struct nocopyassign
-	{
-		nocopyassign(const nocopyassign &) = delete;
-		nocopyassign &operator=(const nocopyassign &) = delete;
-	protected:
-		nocopyassign() = default;
-		~nocopyassign() noexcept = default;
-		nocopyassign(nocopyassign &&) noexcept = default;
-		nocopyassign &operator=(nocopyassign &&) noexcept = default;
+		static constexpr FLOAT128 max() noexcept
+		{
+			return FLT128_MAX;
+		}
+		static constexpr FLOAT128 lowest() noexcept
+		{
+			return -FLT128_MAX;
+		}
 	};
+#endif
 
 	//============================================================
 	// Avoid unused variable warnings
