@@ -32,7 +32,7 @@ namespace solver
 			const solver_parameters_t *params)
 		: matrix_solver_direct_t<FT, 2>(anetlist, name, nets, params, 2)
 		{}
-		unsigned vsolve_non_dynamic(bool newton_raphson) override
+		void vsolve_non_dynamic() override
 		{
 			this->clear_square_mat(this->m_A);
 			this->fill_matrix_and_rhs();
@@ -46,12 +46,6 @@ namespace solver
 			const float_type v0 = (this->m_RHS[0] - b * v1) / a;
 			this->m_new_V[0] = v0;
 			this->m_new_V[1] = v1;
-
-			bool err(false);
-			if (newton_raphson)
-				err = this->check_err();
-			this->store();
-			return (err) ? 2 : 1;
 		}
 
 	};
