@@ -1,16 +1,16 @@
 // license:GPL-2.0+
 // copyright-holders:Couriersud
-/*
- * nld_solver.h
- *
- */
 
 #ifndef NLD_SOLVER_H_
 #define NLD_SOLVER_H_
 
+///
+/// \file nld_solver.h
+///
+
+#include "../plib/pstream.h"
 #include "netlist/nl_base.h"
 #include "nld_matrix_solver.h"
-#include "plib/pstream.h"
 
 #include <map>
 #include <memory>
@@ -24,10 +24,6 @@ namespace netlist
 {
 namespace devices
 {
-	class NETLIB_NAME(solver);
-
-	class matrix_solver_t;
-
 	NETLIB_OBJECT(solver)
 	{
 		NETLIB_CONSTRUCTOR(solver)
@@ -43,9 +39,9 @@ namespace devices
 		void post_start();
 		void stop();
 
-		nl_double gmin() const { return m_params.m_gmin(); }
+		nl_fptype gmin() const { return m_params.m_gmin(); }
 
-		void create_solver_code(std::map<pstring, pstring> &mp);
+		solver::static_compile_container create_solver_code(solver::static_compile_target target);
 
 		NETLIB_UPDATEI();
 		NETLIB_RESETI();
@@ -55,17 +51,22 @@ namespace devices
 		logic_input_t m_fb_step;
 		logic_output_t m_Q_step;
 
-		std::vector<plib::unique_ptr<matrix_solver_t>> m_mat_solvers;
-		std::vector<matrix_solver_t *> m_mat_solvers_all;
-		std::vector<matrix_solver_t *> m_mat_solvers_timestepping;
+		std::vector<plib::unique_ptr<solver::matrix_solver_t>> m_mat_solvers;
+		std::vector<solver::matrix_solver_t *> m_mat_solvers_all;
+		std::vector<solver::matrix_solver_t *> m_mat_solvers_timestepping;
 
-		solver_parameters_t m_params;
+		solver::solver_parameters_t m_params;
 
 		template <typename FT, int SIZE>
-		plib::unique_ptr<matrix_solver_t> create_solver(std::size_t size, const pstring &solvername);
+		plib::unique_ptr<solver::matrix_solver_t> create_solver(std::size_t size,
+			const pstring &solvername, analog_net_t::list_t &nets);
+
+		template <typename FT>
+		plib::unique_ptr<solver::matrix_solver_t> create_solvers(
+			const pstring &sname, analog_net_t::list_t &nets);
 	};
 
 } // namespace devices
 } // namespace netlist
 
-#endif /* NLD_SOLVER_H_ */
+#endif // NLD_SOLVER_H_
