@@ -12,9 +12,9 @@ class pleiads_sound_device : public device_t, public device_sound_interface
 public:
 	pleiads_sound_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock = 0);
 
-	DECLARE_WRITE8_MEMBER( control_a_w );
-	DECLARE_WRITE8_MEMBER( control_b_w );
-	DECLARE_WRITE8_MEMBER( control_c_w );
+	void control_a_w(uint8_t data);
+	void control_b_w(uint8_t data);
+	void control_c_w(uint8_t data);
 
 protected:
 	struct pl_t_state
