@@ -22,11 +22,11 @@ public:
 	trackfld_audio_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock);
 
 	DECLARE_WRITE_LINE_MEMBER(sh_irqtrigger_w);
-	DECLARE_READ8_MEMBER(trackfld_sh_timer_r);
-	DECLARE_READ8_MEMBER(trackfld_speech_r);
-	DECLARE_WRITE8_MEMBER(trackfld_sound_w);
-	DECLARE_READ8_MEMBER(hyperspt_sh_timer_r);
-	DECLARE_WRITE8_MEMBER(hyperspt_sound_w);
+	uint8_t trackfld_sh_timer_r();
+	uint8_t trackfld_speech_r();
+	void trackfld_sound_w(offs_t offset, uint8_t data);
+	uint8_t hyperspt_sh_timer_r();
+	void hyperspt_sound_w(offs_t offset, uint8_t data);
 
 protected:
 	// device-level overrides
