@@ -53,7 +53,7 @@ READ8_MEMBER(a2600_state::cart_over_all_r)
 
 	if (masked_offset < 0x80)
 	{
-		ret = m_tia->read(space, masked_offset&0x7f);
+		ret = m_tia->read(masked_offset&0x7f);
 	}
 	else if (masked_offset < 0x100)
 	{
@@ -62,14 +62,14 @@ READ8_MEMBER(a2600_state::cart_over_all_r)
 	/* 0x100 - 0x1ff already masked out */
 	else if (masked_offset < 0x280)
 	{
-		ret = m_tia->read(space, masked_offset&0x7f);
+		ret = m_tia->read(masked_offset&0x7f);
 	}
 	else if (masked_offset < 0x2a0)
 	{
 #if USE_NEW_RIOT
-		ret = m_riot->io_r(space, masked_offset);
+		ret = m_riot->io_r(masked_offset);
 #else
-		ret = m_riot->read(space, masked_offset);
+		ret = m_riot->read(masked_offset);
 #endif
 	}
 	else if (masked_offset < 0x300)
@@ -89,7 +89,7 @@ WRITE8_MEMBER(a2600_state::cart_over_all_w)
 
 	if (masked_offset < 0x80)
 	{
-		m_tia->write(space, masked_offset & 0x7f, data);
+		m_tia->write(masked_offset & 0x7f, data);
 	}
 	else if (masked_offset < 0x100)
 	{
@@ -98,14 +98,14 @@ WRITE8_MEMBER(a2600_state::cart_over_all_w)
 	/* 0x100 - 0x1ff already masked out */
 	else if (masked_offset < 0x280)
 	{
-		m_tia->write(space, masked_offset & 0x7f, data);
+		m_tia->write(masked_offset & 0x7f, data);
 	}
 	else if (masked_offset < 0x2a0)
 	{
 #if USE_NEW_RIOT
-		m_riot->io_w(space, masked_offset, data);
+		m_riot->io_w(masked_offset, data);
 #else
-		m_riot->write(space, masked_offset, data);
+		m_riot->write(masked_offset, data);
 #endif
 	}
 	else if (masked_offset < 0x300)
@@ -283,7 +283,7 @@ WRITE8_MEMBER(a2600_state::cart_over_tia_w)
 {
 	// Both Cart & TIA see these addresses
 	m_cart->write_bank(space, offset, data);
-	m_tia->write(space, offset, data);
+	m_tia->write(offset, data);
 }
 
 void a2600_base_state::machine_start()
