@@ -70,6 +70,7 @@ public:
 	void showhanc(machine_config &config);
 
 	void init_astoneag();
+	void init_magibomb();
 	void init_showhanc();
 	void init_showhand();
 
@@ -880,7 +881,7 @@ ROM_END
 
 ROM_START( magibomb )
 	ROM_REGION( 0x20000, "maincpu", 0 )
-	ROM_LOAD16_BYTE( "rom1", 0x00000, 0x10000, CRC(f01ab462) SHA1(5c9052f66da166f926910562a6a8aea5397549db) )
+	ROM_LOAD16_BYTE( "rom1", 0x00000, 0x10000, BAD_DUMP CRC(f01ab462) SHA1(5c9052f66da166f926910562a6a8aea5397549db) ) // BADADDR        xxxxxx-xxxxxxxxx
 	ROM_LOAD16_BYTE( "rom2", 0x00001, 0x10000, CRC(ac3224ef) SHA1(810117dc89369eee0f4f5b6744cfbf0cb70ccce6) )
 
 	ROM_REGION( 0x200000, "sprites", 0 )
@@ -1360,11 +1361,20 @@ void astrocorp_state::init_astoneag()
 	decrypt_rom(astoneag_table);
 }
 
+void astrocorp_state::init_magibomb()
+{
+	uint8_t *rom = memregion("maincpu")->base();
+	for (int i = 1; i < 0x20000; i += 2)
+	{
+		rom[i] = bitswap<8>(rom[i], 6, 7, 5, 0, 4, 1, 3, 2);
+	}
+}
+
 GAME( 2000,  showhand,  0,        showhand, showhand, astrocorp_state, init_showhand, ROT0, "Astro Corp.",        "Show Hand (Italy)",                MACHINE_SUPPORTS_SAVE )
 GAME( 2000,  showhanc,  showhand, showhanc, showhanc, astrocorp_state, init_showhanc, ROT0, "Astro Corp.",        "Wang Pai Dui Jue (China)",         MACHINE_SUPPORTS_SAVE )
 GAME( 2002,  skilldrp,  0,        skilldrp, skilldrp, astrocorp_state, empty_init,    ROT0, "Astro Corp.",        "Skill Drop Georgia (Ver. G1.0S)",  MACHINE_SUPPORTS_SAVE )
 GAME( 2003,  speeddrp,  0,        speeddrp, skilldrp, astrocorp_state, empty_init,    ROT0, "Astro Corp.",        "Speed Drop (Ver. 1.06)",           MACHINE_SUPPORTS_SAVE )
-GAME( 200?,  magibomb,  0,        speeddrp, skilldrp, astrocorp_state, empty_init,    ROT0, "Astro Corp.",        "Magic Bomb",                       MACHINE_NOT_WORKING | MACHINE_SUPPORTS_SAVE ) // no gfx dumps, less complex looking encryption
+GAME( 200?,  magibomb,  0,        speeddrp, skilldrp, astrocorp_state, init_magibomb, ROT0, "Astro Corp.",        "Magic Bomb (Ver. BR4.4)",          MACHINE_NOT_WORKING | MACHINE_SUPPORTS_SAVE ) // no gfx dumps, less complex looking encryption
 
 // Encrypted games (not working):
 GAME( 2003?, dinodino,  0,        skilldrp, skilldrp, astrocorp_state, empty_init,    ROT0, "Astro Corp.",        "Dino Dino",                        MACHINE_NOT_WORKING )
